@@ -1,11 +1,18 @@
-import { SEX_LABELS } from './patientFields.js';
+import {
+  MARTIAL_STATUS_LABELS,
+  SEX_LABELS,
+  BLOOD_LABELS,
+  EDUCATIONAL_ATTAINMENT_LABELS,
+  SOCIAL_MEDIA_LABELS,
+  TITLE_LABELS,
+} from './patientFields';
 import {
   INVOICE_STATUS_LABELS,
   INVOICE_INSURER_PAYMENT_STATUS_LABELS,
   INVOICE_ITEMS_CATEGORY_LABELS,
   INVOICE_PATIENT_PAYMENT_STATUSES_LABELS,
-} from './invoices.js';
-import { NOTE_TYPE_LABELS } from './notes.js';
+} from './invoices';
+import { NOTE_TYPE_LABELS } from './notes';
 import {
   REFERRAL_STATUS_LABELS,
   APPOINTMENT_TYPE_LABELS,
@@ -13,7 +20,12 @@ import {
   IMAGING_REQUEST_STATUS_LABELS,
 } from './statuses';
 import { VACCINE_STATUS_LABELS, INJECTION_SITE_LABELS, VACCINE_CATEGORY_LABELS } from './vaccines';
-import { BIRTH_DELIVERY_TYPE_LABELS, BIRTH_TYPE_LABELS } from './births';
+import {
+  ATTENDANT_OF_BIRTH_LABELS,
+  BIRTH_DELIVERY_TYPE_LABELS,
+  BIRTH_TYPE_LABELS,
+  PLACE_OF_BIRTH_LABELS,
+} from './births';
 import {
   REPORT_DATA_SOURCE_LABELS,
   REPORT_DEFAULT_DATE_RANGES_LABELS,
@@ -27,6 +39,7 @@ import { DIAGNOSIS_CERTAINTY_LABELS, PATIENT_ISSUE_LABELS } from './diagnoses';
 import { DRUG_ROUTE_LABELS, REPEATS_LABELS } from './medications';
 import { PLACE_OF_DEATHS, MANNER_OF_DEATHS } from './deaths';
 import { LOCATION_AVAILABILITY_STATUS_LABELS } from './locations';
+import { IMAGING_TYPES } from './imaging';
 
 type EnumKeys = keyof typeof registeredEnums;
 type EnumValues = typeof registeredEnums[EnumKeys];
@@ -40,11 +53,15 @@ type EnumEntries = [EnumKeys, EnumValues][];
 export const registeredEnums = {
   APPOINTMENT_STATUSES,
   APPOINTMENT_TYPE_LABELS,
+  ATTENDANT_OF_BIRTH_LABELS,
   ASSET_NAME_LABELS,
   BIRTH_DELIVERY_TYPE_LABELS,
   BIRTH_TYPE_LABELS,
+  BLOOD_LABELS,
   DIAGNOSIS_CERTAINTY_LABELS,
   DRUG_ROUTE_LABELS,
+  EDUCATIONAL_ATTAINMENT_LABELS,
+  IMAGING_TYPES,
   IMAGING_REQUEST_STATUS_LABELS,
   INJECTION_SITE_LABELS,
   INVOICE_INSURER_PAYMENT_STATUS_LABELS,
@@ -54,8 +71,10 @@ export const registeredEnums = {
   LAB_REQUEST_STATUS_LABELS,
   LOCATION_AVAILABILITY_STATUS_LABELS,
   MANNER_OF_DEATHS,
+  MARTIAL_STATUS_LABELS,
   NOTE_TYPE_LABELS,
   PATIENT_ISSUE_LABELS,
+  PLACE_OF_BIRTH_LABELS,
   PLACE_OF_DEATHS,
   REFERRAL_STATUS_LABELS,
   REPEATS_LABELS,
@@ -64,7 +83,9 @@ export const registeredEnums = {
   REPORT_DEFAULT_DATE_RANGES_LABELS,
   REPORT_STATUS_LABELS,
   SEX_LABELS,
+  SOCIAL_MEDIA_LABELS,
   TEMPLATE_TYPE_LABELS,
+  TITLE_LABELS,
   VACCINE_CATEGORY_LABELS,
   VACCINE_STATUS_LABELS,
 };
@@ -78,11 +99,15 @@ export const registeredEnums = {
 export const translationPrefixes: Record<EnumKeys, string> = {
   APPOINTMENT_STATUSES: 'appointment.property.status',
   APPOINTMENT_TYPE_LABELS: 'appointment.property.types',
+  ATTENDANT_OF_BIRTH_LABELS: 'birth.property.attendantOfBirth',
   ASSET_NAME_LABELS: 'asset.property.name',
   BIRTH_DELIVERY_TYPE_LABELS: 'birth.property.birthDeliveryType',
   BIRTH_TYPE_LABELS: 'birth.property.birthType',
+  BLOOD_LABELS: 'patient.property.blood',
   DIAGNOSIS_CERTAINTY_LABELS: 'diagnosis.property.certainty',
   DRUG_ROUTE_LABELS: 'medication.property.route',
+  EDUCATIONAL_ATTAINMENT_LABELS: 'patient.property.educationalAttainment',
+  IMAGING_TYPES: 'imaging.property.type',
   IMAGING_REQUEST_STATUS_LABELS: 'imaging.property.status',
   INJECTION_SITE_LABELS: 'vaccine.property.injectionSite',
   INVOICE_INSURER_PAYMENT_STATUS_LABELS: 'invoice.property.insurerPaymentStatus',
@@ -92,8 +117,10 @@ export const translationPrefixes: Record<EnumKeys, string> = {
   LAB_REQUEST_STATUS_LABELS: 'lab.property.status',
   LOCATION_AVAILABILITY_STATUS_LABELS: 'bedManagement.property.status',
   MANNER_OF_DEATHS: 'death.property.mannerOfDeath',
+  MARTIAL_STATUS_LABELS: 'patient.property.maritalStatus',
   NOTE_TYPE_LABELS: 'note.property.type',
   PATIENT_ISSUE_LABELS: 'patient.property.issue',
+  PLACE_OF_BIRTH_LABELS: 'birth.property.placeOfBirth',
   PLACE_OF_DEATHS: 'death.property.placeOfDeath',
   REFERRAL_STATUS_LABELS: 'referral.property.status',
   REPEATS_LABELS: 'medication.property.repeats',
@@ -102,7 +129,9 @@ export const translationPrefixes: Record<EnumKeys, string> = {
   REPORT_DEFAULT_DATE_RANGES_LABELS: 'report.property.defaultDateRange',
   REPORT_STATUS_LABELS: 'report.property.status',
   SEX_LABELS: 'patient.property.sex',
+  SOCIAL_MEDIA_LABELS: 'patient.property.socialMedia',
   TEMPLATE_TYPE_LABELS: 'template.property.type',
+  TITLE_LABELS: 'patient.property.title',
   VACCINE_CATEGORY_LABELS: 'vaccine.property.category',
   VACCINE_STATUS_LABELS: 'vaccine.property.status',
 };
