@@ -1,16 +1,32 @@
 import config from 'config';
 import { omit } from 'lodash';
+
 import { initBugsnag } from '@tamanu/shared/services/logging';
+import { ReadSettings } from '@tamanu/settings/reader';
+import { selectFacilityIds } from '@tamanu/shared/utils/configSelectors';
+
 import { closeDatabase, initDatabase, initReporting } from './database';
 import { VERSION } from './middleware/versionCompatibility.js';
 
+/**
+ * @typedef {import('@tamanu/settings/types').FacilitySettingPath} FacilitySettingPath
+ * @typedef {import('@tamanu/settings').ReadSettings} ReadSettings
+ * @typedef {import('sequelize').Sequelize} Sequelize
+ * @typedef {import('@tamanu/shared/models')} Models
+ */
+
 export class ApplicationContext {
-  /** @type {import('sequelize').Sequelize | null} */
+  /** @type {Sequelize | null} */
   sequelize = null;
 
-  /** @type {import('@tamanu/shared/models') | null} */
+  /** @type {Models | null} */
   models = null;
 
+  /**
+   * @type {ReadSettings<FacilitySettingPath> | null}
+   */
+  settings = null;
+
   reportSchemaStores = null;
 
   closeHooks = [];
@@ -20,16 +36,20 @@ export class ApplicationContext {
       if (config.errors.type === 'bugsnag') {
         await initBugsnag({
           ...omit(config.errors, ['enabled', 'type']),
-          appVersion: VERSION,
+          appVersion: [VERSION, process.env.REVISION].filter(Boolean).join('-'),
           appType,
         });
       }
     }
 
+    const facilityIds = selectFacilityIds(config);
     const database = await initDatabase();
     this.sequelize = database.sequelize;
     this.models = database.models;
-
+    this.settings = facilityIds.reduce((acc, facilityId) => {
+      acc[facilityId] = new ReadSettings(this.models, facilityId);
+      return acc;
+    }, {});
     if (config.db.reportSchemas?.enabled) {
       this.reportSchemaStores = await initReporting();
     }
