@@ -1,4 +1,3 @@
-import config from 'config';
 import express from 'express';
 import asyncHandler from 'express-async-handler';
 
@@ -13,13 +12,10 @@ location.get(
   '/$',
   asyncHandler(async (req, res) => {
     req.checkPermission('list', 'Location');
-    if (!config.serverFacilityId) {
-      res.send([]);
-      return;
-    }
+    const { facilityId } = req.query;
     const locations = await req.models.Location.findAll({
       where: {
-        facilityId: config.serverFacilityId,
+        facilityId,
       },
     });
     res.send(locations);
