@@ -1,6 +1,5 @@
 import express from 'express';
 import asyncHandler from 'express-async-handler';
-import config from 'config';
 import { Op, QueryTypes } from 'sequelize';
 import { snakeCase } from 'lodash';
 
@@ -35,6 +34,7 @@ patientRoute.get(
     const {
       models: { Patient },
       params,
+      query: { facilityId },
     } = req;
     req.checkPermission('read', 'Patient');
     const patient = await Patient.findByPk(params.id, {
@@ -42,7 +42,7 @@ patientRoute.get(
     });
     if (!patient) throw new NotFoundError();
 
-    res.send(dbRecordToResponse(patient));
+    res.send(dbRecordToResponse(patient, facilityId));
   }),
 );
 
@@ -53,6 +53,7 @@ patientRoute.put(
       db,
       models: { Patient, PatientAdditionalData, PatientBirthData, PatientSecondaryId },
       params,
+      body: { facilityId, ...body },
     } = req;
     req.checkPermission('read', 'Patient');
     const patient = await Patient.findByPk(params.id);
@@ -65,7 +66,7 @@ patientRoute.put(
 
     await db.transaction(async () => {
       // First check if displayId changed to create a secondaryId record
-      if (req.body.displayId && req.body.displayId !== patient.displayId) {
+      if (body.displayId && body.displayId !== patient.displayId) {
         const oldDisplayIdType = isGeneratedDisplayId(patient.displayId)
           ? 'secondaryIdType-tamanu-display-id'
           : 'secondaryIdType-nhn';
@@ -77,7 +78,7 @@ patientRoute.put(
         });
       }
 
-      await patient.update(requestBodyToRecord(req.body));
+      await patient.update(requestBodyToRecord(body));
 
       const patientAdditionalData = await PatientAdditionalData.findOne({
         where: { patientId: patient.id },
@@ -85,11 +86,11 @@ patientRoute.put(
 
       if (!patientAdditionalData) {
         await PatientAdditionalData.create({
-          ...requestBodyToRecord(req.body),
+          ...requestBodyToRecord(body),
           patientId: patient.id,
         });
       } else {
-        await patientAdditionalData.update(requestBodyToRecord(req.body));
+        await patientAdditionalData.update(requestBodyToRecord(body));
       }
 
       const patientBirth = await PatientBirthData.findOne({
@@ -105,20 +106,18 @@ patientRoute.put(
       await patient.writeFieldValues(req.body.patientFields);
     });
 
-    res.send(dbRecordToResponse(patient));
+    res.send(dbRecordToResponse(patient, facilityId));
   }),
 );
 
 patientRoute.post(
   '/$',
   asyncHandler(async (req, res) => {
-    const {
-      db,
-      models: { Patient, PatientAdditionalData, PatientBirthData },
-    } = req;
+    const { db, models, body } = req;
+    const { Patient, PatientAdditionalData, PatientBirthData, PatientFacility } = models;
     req.checkPermission('create', 'Patient');
-    const requestData = requestBodyToRecord(req.body);
-    const { patientRegistryType, ...patientData } = requestData;
+    const requestData = requestBodyToRecord(body);
+    const { patientRegistryType, facilityId, ...patientData } = requestData;
 
     const patientRecord = await db.transaction(async () => {
       const createdPatient = await Patient.create(patientData);
@@ -140,10 +139,14 @@ patientRoute.post(
           patientId: createdPatient.id,
         });
       }
+
+      // mark for sync in this facility
+      await PatientFacility.create({ facilityId, patientId: createdPatient.id });
+
       return createdPatient;
     });
 
-    res.send(dbRecordToResponse(patientRecord));
+    res.send(dbRecordToResponse(patientRecord, facilityId));
   }),
 );
 
@@ -238,7 +241,13 @@ patientRoute.get(
 
     req.checkPermission('list', 'Patient');
 
-    const { orderBy, order = 'asc', rowsPerPage = 10, page = 0, ...filterParams } = query;
+    const {
+      orderBy,
+      order = 'asc',
+      rowsPerPage = 10,
+      page = 0,
+      ...filterParams
+    } = query;
 
     const sortKey = PATIENT_SORT_KEYS[orderBy] || PATIENT_SORT_KEYS.lastName;
     const sortDirection = order.toLowerCase() === 'asc' ? 'ASC' : 'DESC';
@@ -311,10 +320,7 @@ patientRoute.get(
     const filters = createPatientFilters(filterParams);
     const { whereClauses, filterReplacements } = getWhereClausesAndReplacementsFromFilters(
       filters,
-      {
-        ...filterParams,
-        facilityId: config.serverFacilityId,
-      },
+      filterParams,
     );
 
     const from = isAllPatientsListing
@@ -367,7 +373,7 @@ patientRoute.get(
         LEFT JOIN (
             SELECT ed.encounter_id, jsonb_agg(json_build_object('id', rd.id, 'name', rd.name, 'code', rd.code)) diets
             FROM encounter_diets ed
-            JOIN reference_data rd ON rd.id = ed.diet_id AND rd."type" = 'diet' AND rd.visibility_status = 'current' 
+            JOIN reference_data rd ON rd.id = ed.diet_id AND rd."type" = 'diet' AND rd.visibility_status = 'current'
             WHERE ed.deleted_at is NULL
             GROUP BY ed.encounter_id
         ) diets ON diets.encounter_id = encounters.id
@@ -384,7 +390,7 @@ patientRoute.get(
       ${whereClauses && `WHERE ${whereClauses}`}
     `;
 
-    filterReplacements.facilityId = config.serverFacilityId;
+    filterReplacements.facilityId = filterParams.facilityId;
 
     const countResult = await req.db.query(`SELECT COUNT(1) AS count ${from}`, {
       replacements: filterReplacements,
@@ -489,7 +495,8 @@ patientRoute.post(
     req.checkPermission('read', 'Patient');
     req.checkPermission('create', 'IPSRequest');
 
-    const { models, params } = req;
+    const { models, params, body } = req;
+    const { facilityId } = body;
     const { IPSRequest } = models;
 
     if (!req.body.email) {
@@ -503,7 +510,7 @@ patientRoute.post(
       status: IPS_REQUEST_STATUSES.QUEUED,
     });
 
-    res.send(dbRecordToResponse(ipsRequest));
+    res.send(dbRecordToResponse(ipsRequest, facilityId));
   }),
 );
 
