@@ -8,7 +8,7 @@ import {
   RemoteTimeoutError,
 } from '@tamanu/shared/errors';
 import { SERVER_TYPES, VERSION_COMPATIBILITY_ERRORS } from '@tamanu/constants';
-import { getResponseJsonSafely } from '@tamanu/shared/utils';
+import { getResponseJsonSafely, selectFacilityIds } from '@tamanu/shared/utils';
 import { log } from '@tamanu/shared/services/logging';
 import { fetchWithTimeout } from '@tamanu/shared/utils/fetchWithTimeout';
 import { sleepAsync } from '@tamanu/shared/utils/sleepAsync';
@@ -178,12 +178,13 @@ export class CentralServerConnection {
 
       log.info(`Logging in to ${this.host} as ${email}...`);
 
+      const facilityIds = selectFacilityIds(config);
       const body = await this.fetch('login', {
         method: 'POST',
         body: {
           email,
           password,
-          facilityId: config.serverFacilityId,
+          facilityIds,
           deviceId: this.deviceId,
         },
         awaitConnection: false,
@@ -199,7 +200,7 @@ export class CentralServerConnection {
       log.info(`Received token for user ${body.user.displayName} (${body.user.email})`);
       this.token = body.token;
 
-      return body;
+      return { ...body, serverFacilityIds: facilityIds };
     })();
 
     // await connection attempt, throwing an error if applicable, but always removing connectionPromise
@@ -212,10 +213,11 @@ export class CentralServerConnection {
   }
 
   async startSyncSession({ urgent, lastSyncedTick }) {
+    const facilityIds = selectFacilityIds(config);
     const { sessionId, status } = await this.fetch('sync', {
       method: 'POST',
       body: {
-        facilityId: config.serverFacilityId,
+        facilityIds,
         deviceId: this.deviceId,
         urgent,
         lastSyncedTick,
@@ -245,7 +247,8 @@ export class CentralServerConnection {
   async initiatePull(sessionId, since) {
     // first, set the pull filter on the central server, which will kick of a snapshot of changes
     // to pull
-    const body = { since, facilityId: config.serverFacilityId, deviceId: this.deviceId };
+    const facilityIds = selectFacilityIds(config);
+    const body = { since, facilityIds, deviceId: this.deviceId };
     await this.fetch(`sync/${sessionId}/pull/initiate`, { method: 'POST', body });
 
     // then, poll the pull/ready endpoint until we get a valid response - it takes a while for
