@@ -2,7 +2,6 @@ import { Sequelize } from 'sequelize';
 import { SYNC_DIRECTIONS } from '@tamanu/constants';
 import { Model } from './Model';
 import { buildPatientSyncFilterViaPatientId } from './buildPatientSyncFilterViaPatientId';
-import { onSaveMarkPatientForSync } from './onSaveMarkPatientForSync';
 import { buildPatientLinkedLookupFilter } from './buildPatientLinkedLookupFilter';
 
 export class PatientContact extends Model {
@@ -19,14 +18,12 @@ export class PatientContact extends Model {
           allowNull: false,
         },
         connectionDetails: Sequelize.JSONB,
-        deletionStatus: Sequelize.TEXT,
       },
       {
         ...options,
         syncDirection: SYNC_DIRECTIONS.BIDIRECTIONAL,
       },
     );
-    onSaveMarkPatientForSync(this);
   }
 
   static initRelations(models) {
